@@ -2,21 +2,20 @@
 // The .NET Foundation licenses this file to you under the MIT license.
 // See the LICENSE file in the project root for more information.
 
-[assembly:System.Reflection.AssemblyVersionAttribute("4.0.0.0")]
+[assembly:System.Reflection.AssemblyVersionAttribute("2.0.0.0")]
 [assembly:System.CLSCompliantAttribute(true)]
-[assembly:System.Diagnostics.DebuggableAttribute((System.Diagnostics.DebuggableAttribute.DebuggingModes)(258))]
+[assembly:System.Diagnostics.DebuggableAttribute((System.Diagnostics.DebuggableAttribute.DebuggingModes)(2))]
 [assembly:System.Reflection.AssemblyCompanyAttribute("Mono development team")]
 [assembly:System.Reflection.AssemblyCopyrightAttribute("(c) Various Mono authors")]
 [assembly:System.Reflection.AssemblyDefaultAliasAttribute("System.Data.OracleClient.dll")]
 [assembly:System.Reflection.AssemblyDescriptionAttribute("System.Data.OracleClient.dll")]
-[assembly:System.Reflection.AssemblyFileVersionAttribute("4.0.30319.17020")]
-[assembly:System.Reflection.AssemblyInformationalVersionAttribute("4.0.30319.17020")]
+[assembly:System.Reflection.AssemblyFileVersionAttribute("2.0.50727.1433")]
+[assembly:System.Reflection.AssemblyInformationalVersionAttribute("2.0.50727.1433")]
 [assembly:System.Reflection.AssemblyProductAttribute("Mono Common Language Infrastructure")]
 [assembly:System.Reflection.AssemblyTitleAttribute("System.Data.OracleClient.dll")]
 [assembly:System.Resources.NeutralResourcesLanguageAttribute("en-US")]
-[assembly:System.Resources.SatelliteContractVersionAttribute("4.0.0.0")]
+[assembly:System.Resources.SatelliteContractVersionAttribute("2.0.0.0")]
 [assembly:System.Runtime.CompilerServices.DependencyAttribute("System.Data,", (System.Runtime.CompilerServices.LoadHint)(1))]
-[assembly:System.Runtime.CompilerServices.ReferenceAssemblyAttribute]
 [assembly:System.Runtime.CompilerServices.RuntimeCompatibilityAttribute(WrapNonExceptionThrows=true)]
 [assembly:System.Runtime.InteropServices.ComCompatibleVersionAttribute(1, 0, 3300, 0)]
 [assembly:System.Runtime.InteropServices.ComVisibleAttribute(false)]
@@ -98,7 +97,6 @@ namespace System.Data.OracleClient
     [System.Runtime.InteropServices.StructLayoutAttribute(System.Runtime.InteropServices.LayoutKind.Sequential)]
     public partial struct OracleBinary : System.Data.SqlTypes.INullable, System.IComparable
     {
-        private object _dummy;
         public static readonly System.Data.OracleClient.OracleBinary Null;
         public OracleBinary(byte[] b) { throw null;}
         public bool IsNull { get { throw null; } }
@@ -137,7 +135,6 @@ namespace System.Data.OracleClient
     [System.Runtime.InteropServices.StructLayoutAttribute(System.Runtime.InteropServices.LayoutKind.Sequential)]
     public partial struct OracleBoolean : System.IComparable
     {
-        private int _dummyPrimitive;
         public static readonly System.Data.OracleClient.OracleBoolean False;
         public static readonly System.Data.OracleClient.OracleBoolean Null;
         public static readonly System.Data.OracleClient.OracleBoolean One;
@@ -182,16 +179,19 @@ namespace System.Data.OracleClient
     {
         internal OracleClientFactory() { }
         public static readonly System.Data.OracleClient.OracleClientFactory Instance;
+        [System.MonoTODOAttribute]
+        public override bool CanCreateDataSourceEnumerator { get { throw null; } }
         public override System.Data.Common.DbCommand CreateCommand() { throw null; }
         public override System.Data.Common.DbCommandBuilder CreateCommandBuilder() { throw null; }
         public override System.Data.Common.DbConnection CreateConnection() { throw null; }
         public override System.Data.Common.DbConnectionStringBuilder CreateConnectionStringBuilder() { throw null; }
         public override System.Data.Common.DbDataAdapter CreateDataAdapter() { throw null; }
+        public override System.Data.Common.DbDataSourceEnumerator CreateDataSourceEnumerator() { throw null; }
         public override System.Data.Common.DbParameter CreateParameter() { throw null; }
         public override System.Security.CodeAccessPermission CreatePermission(System.Security.Permissions.PermissionState state) { throw null; }
     }
     [System.ComponentModel.DefaultEventAttribute("RecordsAffected")]
-    [System.ComponentModel.DesignerAttribute("Microsoft.VSDesigner.Data.VS.OracleCommandDesigner, Microsoft.VSDesigner, Version=0.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a")]
+    [System.ComponentModel.DesignerAttribute("Microsoft.VSDesigner.Data.VS.OracleCommandDesigner, Microsoft.VSDesigner, Version=8.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a")]
     [System.ComponentModel.ToolboxItemAttribute(true)]
     public sealed partial class OracleCommand : System.Data.Common.DbCommand, System.ICloneable
     {
@@ -200,7 +200,7 @@ namespace System.Data.OracleClient
         public OracleCommand(string commandText, System.Data.OracleClient.OracleConnection connection) { }
         public OracleCommand(string commandText, System.Data.OracleClient.OracleConnection connection, System.Data.OracleClient.OracleTransaction tx) { }
         [System.ComponentModel.DefaultValueAttribute("")]
-        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Oracle.Design.OracleCommandTextEditor, Microsoft.VSDesigner, Version=0.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
+        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Oracle.Design.OracleCommandTextEditor, Microsoft.VSDesigner, Version=8.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
         [System.ComponentModel.RefreshPropertiesAttribute((System.ComponentModel.RefreshProperties)(1))]
         public override string CommandText { get { throw null; } set { } }
         [System.ComponentModel.BrowsableAttribute(false)]
@@ -211,7 +211,7 @@ namespace System.Data.OracleClient
         [System.ComponentModel.RefreshPropertiesAttribute((System.ComponentModel.RefreshProperties)(1))]
         public override System.Data.CommandType CommandType { get { throw null; } set { } }
         [System.ComponentModel.DefaultValueAttribute(null)]
-        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DbConnectionEditor, Microsoft.VSDesigner, Version=0.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
+        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DbConnectionEditor, Microsoft.VSDesigner, Version=8.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
         public new System.Data.OracleClient.OracleConnection Connection { get { throw null; } set { } }
         [System.MonoTODOAttribute]
         protected override System.Data.Common.DbConnection DbConnection { get { throw null; } set { } }
@@ -237,6 +237,7 @@ namespace System.Data.OracleClient
         public object Clone() { throw null; }
         protected override System.Data.Common.DbParameter CreateDbParameter() { throw null; }
         public new System.Data.OracleClient.OracleParameter CreateParameter() { throw null; }
+        protected override void Dispose(bool disposing) { }
         protected override System.Data.Common.DbDataReader ExecuteDbDataReader(System.Data.CommandBehavior behavior) { throw null; }
         public override int ExecuteNonQuery() { throw null; }
         public int ExecuteOracleNonQuery(out System.Data.OracleClient.OracleString rowid) { rowid = default(System.Data.OracleClient.OracleString); throw null; }
@@ -245,36 +246,36 @@ namespace System.Data.OracleClient
         public new System.Data.OracleClient.OracleDataReader ExecuteReader(System.Data.CommandBehavior behavior) { throw null; }
         public override object ExecuteScalar() { throw null; }
         public override void Prepare() { }
-        public void ResetCommandTimeout() { }
     }
     public sealed partial class OracleCommandBuilder : System.Data.Common.DbCommandBuilder
     {
         public OracleCommandBuilder() { }
         public OracleCommandBuilder(System.Data.OracleClient.OracleDataAdapter adapter) { }
-        public override System.Data.Common.CatalogLocation CatalogLocation { get { throw null; } set { } }
-        public override string CatalogSeparator { get { throw null; } set { } }
         [System.ComponentModel.DefaultValueAttribute(null)]
         public new System.Data.OracleClient.OracleDataAdapter DataAdapter { get { throw null; } set { } }
-        public override string SchemaSeparator { get { throw null; } set { } }
+        [System.ComponentModel.BrowsableAttribute(false)]
+        [System.ComponentModel.DesignerSerializationVisibilityAttribute((System.ComponentModel.DesignerSerializationVisibility)(0))]
+        public override string QuotePrefix { get { throw null; } set { } }
+        [System.ComponentModel.BrowsableAttribute(false)]
+        [System.ComponentModel.DesignerSerializationVisibilityAttribute((System.ComponentModel.DesignerSerializationVisibility)(0))]
+        public override string QuoteSuffix { get { throw null; } set { } }
         [System.MonoTODOAttribute]
-        protected override void ApplyParameterInfo(System.Data.Common.DbParameter parameter, System.Data.DataRow datarow, System.Data.StatementType statementType, bool whereClause) { }
+        protected override void ApplyParameterInfo(System.Data.Common.DbParameter dbParameter, System.Data.DataRow row, System.Data.StatementType statementType, bool whereClause) { }
         public static void DeriveParameters(System.Data.OracleClient.OracleCommand command) { }
+        protected override void Dispose(bool disposing) { }
         public new System.Data.OracleClient.OracleCommand GetDeleteCommand() { throw null; }
-        public new System.Data.OracleClient.OracleCommand GetDeleteCommand(bool useColumnsForParameterNames) { throw null; }
         public new System.Data.OracleClient.OracleCommand GetInsertCommand() { throw null; }
-        public new System.Data.OracleClient.OracleCommand GetInsertCommand(bool useColumnsForParameterNames) { throw null; }
         [System.MonoTODOAttribute]
-        protected override string GetParameterName(int parameterOrdinal) { throw null; }
+        protected override string GetParameterName(int position) { throw null; }
         [System.MonoTODOAttribute]
         protected override string GetParameterName(string parameterName) { throw null; }
         [System.MonoTODOAttribute]
-        protected override string GetParameterPlaceholder(int parameterOrdinal) { throw null; }
+        protected override string GetParameterPlaceholder(int position) { throw null; }
         public new System.Data.OracleClient.OracleCommand GetUpdateCommand() { throw null; }
-        public new System.Data.OracleClient.OracleCommand GetUpdateCommand(bool useColumnsForParameterNames) { throw null; }
-        public override string QuoteIdentifier(string unquotedIdentifier) { throw null; }
+        [System.MonoTODOAttribute("Figure out what else needs to be cleaned up when we refresh.")]
+        public override void RefreshSchema() { }
         [System.MonoTODOAttribute]
         protected override void SetRowUpdatingHandler(System.Data.Common.DbDataAdapter adapter) { }
-        public override string UnquoteIdentifier(string quotedIdentifier) { throw null; }
     }
     [System.ComponentModel.DefaultEventAttribute("InfoMessage")]
     public sealed partial class OracleConnection : System.Data.Common.DbConnection, System.ICloneable
@@ -282,7 +283,7 @@ namespace System.Data.OracleClient
         public OracleConnection() { }
         public OracleConnection(string connectionString) { }
         [System.ComponentModel.DefaultValueAttribute("")]
-        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Oracle.Design.OracleConnectionStringEditor, Microsoft.VSDesigner, Version=0.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
+        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Oracle.Design.OracleConnectionStringEditor, Microsoft.VSDesigner, Version=8.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
         [System.ComponentModel.RefreshPropertiesAttribute((System.ComponentModel.RefreshProperties)(1))]
         [System.ComponentModel.SettingsBindableAttribute(true)]
         public override string ConnectionString { get { throw null; } set { } }
@@ -308,8 +309,6 @@ namespace System.Data.OracleClient
         public new System.Data.OracleClient.OracleTransaction BeginTransaction(System.Data.IsolationLevel il) { throw null; }
         [System.MonoTODOAttribute]
         public override void ChangeDatabase(string value) { }
-        public static void ClearAllPools() { }
-        public static void ClearPool(System.Data.OracleClient.OracleConnection connection) { }
         public override void Close() { }
         public new System.Data.OracleClient.OracleCommand CreateCommand() { throw null; }
         protected override System.Data.Common.DbCommand CreateDbCommand() { throw null; }
@@ -317,7 +316,6 @@ namespace System.Data.OracleClient
         protected override void Dispose(bool disposing) { }
         [System.MonoTODOAttribute]
         public void EnlistDistributedTransaction(System.EnterpriseServices.ITransaction distributedTransaction) { }
-        public override void EnlistTransaction(System.Transactions.Transaction transaction) { }
         public override System.Data.DataTable GetSchema() { throw null; }
         public override System.Data.DataTable GetSchema(string collectionName) { throw null; }
         public override System.Data.DataTable GetSchema(string collectionName, string[] restrictionValues) { throw null; }
@@ -373,29 +371,28 @@ namespace System.Data.OracleClient
         public override System.Collections.ICollection Values { get { throw null; } }
         public override void Clear() { }
         public override bool ContainsKey(string keyword) { throw null; }
-        protected override void GetProperties(System.Collections.Hashtable propertyDescriptors) { }
         public override bool Remove(string keyword) { throw null; }
         [System.MonoNotSupportedAttribute("")]
         public override bool ShouldSerialize(string keyword) { throw null; }
         public override bool TryGetValue(string keyword, out object value) { value = default(object); throw null; }
     }
     [System.ComponentModel.DefaultEventAttribute("RowUpdated")]
-    [System.ComponentModel.DesignerAttribute("Microsoft.VSDesigner.Data.VS.OracleDataAdapterDesigner, Microsoft.VSDesigner, Version=0.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a")]
-    [System.ComponentModel.ToolboxItemAttribute("Microsoft.VSDesigner.Data.VS.OracleDataAdapterToolboxItem, Microsoft.VSDesigner, Version=0.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a")]
-    public sealed partial class OracleDataAdapter : System.Data.Common.DbDataAdapter, System.Data.IDataAdapter, System.Data.IDbDataAdapter, System.ICloneable
+    [System.ComponentModel.DesignerAttribute("Microsoft.VSDesigner.Data.VS.OracleDataAdapterDesigner, Microsoft.VSDesigner, Version=8.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a")]
+    [System.ComponentModel.ToolboxItemAttribute("Microsoft.VSDesigner.Data.VS.OracleDataAdapterToolboxItem, Microsoft.VSDesigner, Version=8.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a")]
+    public sealed partial class OracleDataAdapter : System.Data.Common.DbDataAdapter, System.Data.IDataAdapter, System.Data.IDbDataAdapter
     {
         public OracleDataAdapter() { }
         public OracleDataAdapter(System.Data.OracleClient.OracleCommand selectCommand) { }
         public OracleDataAdapter(string selectCommandText, System.Data.OracleClient.OracleConnection selectConnection) { }
         public OracleDataAdapter(string selectCommandText, string selectConnectionString) { }
         [System.ComponentModel.DefaultValueAttribute(null)]
-        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DBCommandEditor, Microsoft.VSDesigner, Version=0.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
+        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DBCommandEditor, Microsoft.VSDesigner, Version=8.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
         public new System.Data.OracleClient.OracleCommand DeleteCommand { get { throw null; } set { } }
         [System.ComponentModel.DefaultValueAttribute(null)]
-        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DBCommandEditor, Microsoft.VSDesigner, Version=0.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
+        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DBCommandEditor, Microsoft.VSDesigner, Version=8.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
         public new System.Data.OracleClient.OracleCommand InsertCommand { get { throw null; } set { } }
         [System.ComponentModel.DefaultValueAttribute(null)]
-        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DBCommandEditor, Microsoft.VSDesigner, Version=0.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
+        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DBCommandEditor, Microsoft.VSDesigner, Version=8.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
         public new System.Data.OracleClient.OracleCommand SelectCommand { get { throw null; } set { } }
         System.Data.IDbCommand System.Data.IDbDataAdapter.DeleteCommand { get { throw null; } set { } }
         System.Data.IDbCommand System.Data.IDbDataAdapter.InsertCommand { get { throw null; } set { } }
@@ -403,22 +400,14 @@ namespace System.Data.OracleClient
         System.Data.IDbCommand System.Data.IDbDataAdapter.UpdateCommand { get { throw null; } set { } }
         public override int UpdateBatchSize { get { throw null; } set { } }
         [System.ComponentModel.DefaultValueAttribute(null)]
-        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DBCommandEditor, Microsoft.VSDesigner, Version=0.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
+        [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DBCommandEditor, Microsoft.VSDesigner, Version=8.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
         public new System.Data.OracleClient.OracleCommand UpdateCommand { get { throw null; } set { } }
         public event System.Data.OracleClient.OracleRowUpdatedEventHandler RowUpdated { add { } remove { } }
         public event System.Data.OracleClient.OracleRowUpdatingEventHandler RowUpdating { add { } remove { } }
-        protected override int AddToBatch(System.Data.IDbCommand command) { throw null; }
-        protected override void ClearBatch() { }
         protected override System.Data.Common.RowUpdatedEventArgs CreateRowUpdatedEvent(System.Data.DataRow dataRow, System.Data.IDbCommand command, System.Data.StatementType statementType, System.Data.Common.DataTableMapping tableMapping) { throw null; }
         protected override System.Data.Common.RowUpdatingEventArgs CreateRowUpdatingEvent(System.Data.DataRow dataRow, System.Data.IDbCommand command, System.Data.StatementType statementType, System.Data.Common.DataTableMapping tableMapping) { throw null; }
-        protected override int ExecuteBatch() { throw null; }
-        protected override System.Data.IDataParameter GetBatchedParameter(int commandIdentifier, int parameterIndex) { throw null; }
-        protected override bool GetBatchedRecordsAffected(int commandIdentifier, out int recordsAffected, out System.Exception error) { recordsAffected = default(int); error = default(System.Exception); throw null; }
-        protected override void InitializeBatching() { }
         protected override void OnRowUpdated(System.Data.Common.RowUpdatedEventArgs value) { }
         protected override void OnRowUpdating(System.Data.Common.RowUpdatingEventArgs value) { }
-        object System.ICloneable.Clone() { throw null; }
-        protected override void TerminateBatching() { }
     }
     public sealed partial class OracleDataReader : System.Data.Common.DbDataReader
     {
@@ -431,6 +420,7 @@ namespace System.Data.OracleClient
         public override object this[string name] { get { throw null; } }
         public override int RecordsAffected { get { throw null; } }
         public override void Close() { }
+        ~OracleDataReader() { }
         public override bool GetBoolean(int i) { throw null; }
         public override byte GetByte(int i) { throw null; }
         public override long GetBytes(int i, long fieldOffset, byte[] buffer2, int bufferoffset, int length) { throw null; }
@@ -480,7 +470,6 @@ namespace System.Data.OracleClient
     [System.Runtime.InteropServices.StructLayoutAttribute(System.Runtime.InteropServices.LayoutKind.Sequential)]
     public partial struct OracleDateTime : System.Data.SqlTypes.INullable, System.IComparable
     {
-        private object _dummy;
         public static readonly System.Data.OracleClient.OracleDateTime MaxValue;
         public static readonly System.Data.OracleClient.OracleDateTime MinValue;
         public static readonly System.Data.OracleClient.OracleDateTime Null;
@@ -575,7 +564,6 @@ namespace System.Data.OracleClient
         [System.MonoTODOAttribute]
         public override void SetLength(long value) { }
         public override void Write(byte[] buffer, int offset, int count) { }
-        public override void WriteByte(byte value) { }
     }
     public enum OracleLobOpenMode
     {
@@ -585,7 +573,6 @@ namespace System.Data.OracleClient
     [System.Runtime.InteropServices.StructLayoutAttribute(System.Runtime.InteropServices.LayoutKind.Sequential)]
     public partial struct OracleMonthSpan : System.Data.SqlTypes.INullable, System.IComparable
     {
-        private int _dummyPrimitive;
         public static readonly System.Data.OracleClient.OracleMonthSpan MaxValue;
         public static readonly System.Data.OracleClient.OracleMonthSpan MinValue;
         public static readonly System.Data.OracleClient.OracleMonthSpan Null;
@@ -618,7 +605,6 @@ namespace System.Data.OracleClient
     [System.Runtime.InteropServices.StructLayoutAttribute(System.Runtime.InteropServices.LayoutKind.Sequential)]
     public partial struct OracleNumber : System.Data.SqlTypes.INullable, System.IComparable
     {
-        private object _dummy;
         public static readonly System.Data.OracleClient.OracleNumber E;
         public static readonly int MaxPrecision;
         public static readonly int MaxScale;
@@ -708,7 +694,7 @@ namespace System.Data.OracleClient
         public static System.Data.OracleClient.OracleNumber Truncate(System.Data.OracleClient.OracleNumber n, int position) { throw null; }
     }
     [System.ComponentModel.TypeConverterAttribute("System.Data.OracleClient.OracleParameter.OracleParameterConverter")]
-    public sealed partial class OracleParameter : System.Data.Common.DbParameter, System.Data.IDataParameter, System.Data.IDbDataParameter, System.ICloneable
+    public sealed partial class OracleParameter : System.Data.Common.DbParameter, System.Data.IDataParameter, System.Data.IDbDataParameter, System.ICloneable, System.IDisposable
     {
         public OracleParameter() { }
         public OracleParameter(string name, System.Data.OracleClient.OracleType oracleType) { }
@@ -745,12 +731,14 @@ namespace System.Data.OracleClient
         [System.ComponentModel.RefreshPropertiesAttribute((System.ComponentModel.RefreshProperties)(1))]
         [System.ComponentModel.TypeConverterAttribute(typeof(System.ComponentModel.StringConverter))]
         public override object Value { get { throw null; } set { } }
+        public void Dispose() { }
+        ~OracleParameter() { }
         public override void ResetDbType() { }
         public void ResetOracleType() { }
         object System.ICloneable.Clone() { throw null; }
         public override string ToString() { throw null; }
     }
-    [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DBParametersEditor, Microsoft.VSDesigner, Version=0.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
+    [System.ComponentModel.EditorAttribute("Microsoft.VSDesigner.Data.Design.DBParametersEditor, Microsoft.VSDesigner, Version=8.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a", typeof(System.Drawing.Design.UITypeEditor))]
     [System.ComponentModel.ListBindableAttribute(false)]
     public sealed partial class OracleParameterCollection : System.Data.Common.DbParameterCollection
     {
@@ -771,13 +759,11 @@ namespace System.Data.OracleClient
         public System.Data.OracleClient.OracleParameter Add(string parameterName, object value) { throw null; }
         public override void AddRange(System.Array values) { }
         public void AddRange(System.Data.OracleClient.OracleParameter[] values) { }
-        public System.Data.OracleClient.OracleParameter AddWithValue(string parameterName, object value) { throw null; }
         public override void Clear() { }
         public bool Contains(System.Data.OracleClient.OracleParameter value) { throw null; }
         public override bool Contains(object value) { throw null; }
         public override bool Contains(string parameterName) { throw null; }
         public override void CopyTo(System.Array array, int index) { }
-        public void CopyTo(System.Data.OracleClient.OracleParameter[] array, int index) { }
         public override System.Collections.IEnumerator GetEnumerator() { throw null; }
         protected override System.Data.Common.DbParameter GetParameter(int index) { throw null; }
         protected override System.Data.Common.DbParameter GetParameter(string parameterName) { throw null; }
@@ -795,31 +781,17 @@ namespace System.Data.OracleClient
     }
     [System.MonoTODOAttribute("Current MS implementation of Data Provider requires FullTrust")]
     [System.SerializableAttribute]
-    public sealed partial class OraclePermission : System.Security.CodeAccessPermission, System.Security.Permissions.IUnrestrictedPermission
+    public sealed partial class OraclePermission : System.Data.Common.DBDataPermission
     {
-        public OraclePermission(System.Security.Permissions.PermissionState state) { }
-        public bool AllowBlankPassword { get { throw null; } set { } }
-        public void Add(string connectionString, string restrictions, System.Data.KeyRestrictionBehavior behavior) { }
+        public OraclePermission(System.Security.Permissions.PermissionState state) : base (default(System.Data.Common.DBDataPermission)) { }
         public override System.Security.IPermission Copy() { throw null; }
-        public override void FromXml(System.Security.SecurityElement securityElement) { }
-        public override System.Security.IPermission Intersect(System.Security.IPermission target) { throw null; }
-        public override bool IsSubsetOf(System.Security.IPermission target) { throw null; }
-        public bool IsUnrestricted() { throw null; }
-        public override System.Security.SecurityElement ToXml() { throw null; }
-        public override System.Security.IPermission Union(System.Security.IPermission target) { throw null; }
     }
     [System.AttributeUsageAttribute((System.AttributeTargets)(109), AllowMultiple=true, Inherited=false)]
     [System.SerializableAttribute]
-    public sealed partial class OraclePermissionAttribute : System.Security.Permissions.CodeAccessSecurityAttribute
+    public sealed partial class OraclePermissionAttribute : System.Data.Common.DBDataPermissionAttribute
     {
         public OraclePermissionAttribute(System.Security.Permissions.SecurityAction action) : base (default(System.Security.Permissions.SecurityAction)) { }
-        public bool AllowBlankPassword { get { throw null; } set { } }
-        public string ConnectionString { get { throw null; } set { } }
-        public System.Data.KeyRestrictionBehavior KeyRestrictionBehavior { get { throw null; } set { } }
-        public string KeyRestrictions { get { throw null; } set { } }
         public override System.Security.IPermission CreatePermission() { throw null; }
-        public bool ShouldSerializeConnectionString() { throw null; }
-        public bool ShouldSerializeKeyRestrictions() { throw null; }
     }
     public sealed partial class OracleRowUpdatedEventArgs : System.Data.Common.RowUpdatedEventArgs
     {
@@ -837,7 +809,6 @@ namespace System.Data.OracleClient
     [System.Runtime.InteropServices.StructLayoutAttribute(System.Runtime.InteropServices.LayoutKind.Sequential)]
     public partial struct OracleString : System.Data.SqlTypes.INullable, System.IComparable
     {
-        private object _dummy;
         public static readonly System.Data.OracleClient.OracleString Empty;
         public static readonly System.Data.OracleClient.OracleString Null;
         public OracleString(string s) { throw null;}
@@ -871,7 +842,6 @@ namespace System.Data.OracleClient
     [System.Runtime.InteropServices.StructLayoutAttribute(System.Runtime.InteropServices.LayoutKind.Sequential)]
     public partial struct OracleTimeSpan : System.Data.SqlTypes.INullable, System.IComparable
     {
-        private object _dummy;
         public static readonly System.Data.OracleClient.OracleTimeSpan MaxValue;
         public static readonly System.Data.OracleClient.OracleTimeSpan MinValue;
         public static readonly System.Data.OracleClient.OracleTimeSpan Null;
