@@ -4,13 +4,12 @@
 
 [assembly:System.Reflection.AssemblyVersionAttribute("4.0.0.0")]
 [assembly:System.CLSCompliantAttribute(true)]
-[assembly:System.Diagnostics.DebuggableAttribute((System.Diagnostics.DebuggableAttribute.DebuggingModes)(258))]
 [assembly:System.Reflection.AssemblyCompanyAttribute("Mono development team")]
 [assembly:System.Reflection.AssemblyCopyrightAttribute("(c) Various Mono authors")]
 [assembly:System.Reflection.AssemblyDefaultAliasAttribute("System.Data.Services.dll")]
 [assembly:System.Reflection.AssemblyDescriptionAttribute("System.Data.Services.dll")]
-[assembly:System.Reflection.AssemblyFileVersionAttribute("4.0.30319.17020")]
-[assembly:System.Reflection.AssemblyInformationalVersionAttribute("4.0.30319.17020")]
+[assembly:System.Reflection.AssemblyFileVersionAttribute("4.0.30319.1")]
+[assembly:System.Reflection.AssemblyInformationalVersionAttribute("4.0.30319.1")]
 [assembly:System.Reflection.AssemblyProductAttribute("Mono Common Language Infrastructure")]
 [assembly:System.Reflection.AssemblyTitleAttribute("System.Data.Services.dll")]
 [assembly:System.Resources.NeutralResourcesLanguageAttribute("en-US")]
@@ -64,16 +63,15 @@ namespace System.Data.Services
     }
     public sealed partial class DataServiceBehavior
     {
-        internal DataServiceBehavior() { }
+        public DataServiceBehavior() { }
         public bool AcceptCountRequests { [System.Runtime.CompilerServices.CompilerGeneratedAttribute]get { throw null; } [System.Runtime.CompilerServices.CompilerGeneratedAttribute]set { } }
         public bool AcceptProjectionRequests { [System.Runtime.CompilerServices.CompilerGeneratedAttribute]get { throw null; } [System.Runtime.CompilerServices.CompilerGeneratedAttribute]set { } }
-        public bool AcceptReplaceFunctionInQuery { [System.Runtime.CompilerServices.CompilerGeneratedAttribute]get { throw null; } [System.Runtime.CompilerServices.CompilerGeneratedAttribute]set { } }
         public bool InvokeInterceptorsOnLinkDelete { [System.Runtime.CompilerServices.CompilerGeneratedAttribute]get { throw null; } [System.Runtime.CompilerServices.CompilerGeneratedAttribute]set { } }
         public System.Data.Services.Common.DataServiceProtocolVersion MaxProtocolVersion { [System.Runtime.CompilerServices.CompilerGeneratedAttribute]get { throw null; } [System.Runtime.CompilerServices.CompilerGeneratedAttribute]set { } }
     }
     public sealed partial class DataServiceConfiguration : System.Data.Services.IDataServiceConfiguration
     {
-        internal DataServiceConfiguration() { }
+        public DataServiceConfiguration() { }
         public System.Data.Services.DataServiceBehavior DataServiceBehavior { get { throw null; } }
         public bool EnableTypeConversion { get { throw null; } set { } }
         public int MaxBatchCount { get { throw null; } set { } }
@@ -117,7 +115,7 @@ namespace System.Data.Services
     }
     public sealed partial class DataServiceOperationContext
     {
-        internal DataServiceOperationContext() { }
+        public DataServiceOperationContext() { }
         public System.Uri AbsoluteRequestUri { get { throw null; } }
         public System.Uri AbsoluteServiceUri { get { throw null; } }
         public bool IsBatchRequest { get { throw null; } }
@@ -136,7 +134,7 @@ namespace System.Data.Services
     }
     public sealed partial class DataServiceProcessingPipelineEventArgs : System.EventArgs
     {
-        internal DataServiceProcessingPipelineEventArgs() { }
+        public DataServiceProcessingPipelineEventArgs() { }
         public System.Data.Services.DataServiceOperationContext OperationContext { get { throw null; } }
     }
     [System.ServiceModel.Activation.AspNetCompatibilityRequirementsAttribute(RequirementsMode=(System.ServiceModel.Activation.AspNetCompatibilityRequirementsMode)(1))]
@@ -193,7 +191,7 @@ namespace System.Data.Services
     }
     public partial class HandleExceptionArgs
     {
-        internal HandleExceptionArgs() { }
+        public HandleExceptionArgs() { }
         public System.Exception Exception { [System.Runtime.CompilerServices.CompilerGeneratedAttribute]get { throw null; } [System.Runtime.CompilerServices.CompilerGeneratedAttribute]set { } }
         public string ResponseContentType { [System.Runtime.CompilerServices.CompilerGeneratedAttribute]get { throw null; } }
         public int ResponseStatusCode { [System.Runtime.CompilerServices.CompilerGeneratedAttribute]get { throw null; } }
@@ -288,7 +286,7 @@ namespace System.Data.Services
     }
     public sealed partial class ProcessRequestArgs
     {
-        internal ProcessRequestArgs() { }
+        public ProcessRequestArgs() { }
         public bool IsBatchOperation { [System.Runtime.CompilerServices.CompilerGeneratedAttribute]get { throw null; } }
         public System.Data.Services.DataServiceOperationContext OperationContext { [System.Runtime.CompilerServices.CompilerGeneratedAttribute]get { throw null; } }
         public System.Uri RequestUri { [System.Runtime.CompilerServices.CompilerGeneratedAttribute]get { throw null; } }
@@ -323,24 +321,6 @@ namespace System.Data.Services
         None = 0,
     }
 }
-namespace System.Data.Services.Configuration
-{
-    public sealed partial class DataServicesFeaturesSection : System.Configuration.ConfigurationSection
-    {
-        public DataServicesFeaturesSection() { }
-        public System.Data.Services.Configuration.DataServicesReplaceFunctionFeature ReplaceFunction { get { throw null; } set { } }
-    }
-    public partial class DataServicesReplaceFunctionFeature : System.Configuration.ConfigurationElement
-    {
-        public DataServicesReplaceFunctionFeature() { }
-        public bool Enable { get { throw null; } set { } }
-    }
-    public sealed partial class DataServicesSectionGroup : System.Configuration.ConfigurationSectionGroup
-    {
-        public DataServicesSectionGroup() { }
-        public System.Data.Services.Configuration.DataServicesFeaturesSection Features { get { throw null; } }
-    }
-}
 namespace System.Data.Services.Internal
 {
     [System.ComponentModel.EditorBrowsableAttribute((System.ComponentModel.EditorBrowsableState)(1))]
