@@ -4,25 +4,24 @@
 
 [assembly:System.Reflection.AssemblyVersionAttribute("4.0.0.0")]
 [assembly:System.CLSCompliantAttribute(true)]
-[assembly:System.Diagnostics.DebuggableAttribute(System.Diagnostics.DebuggableAttribute.DebuggingModes.IgnoreSymbolStoreSequencePoints)]
+[assembly:System.Diagnostics.DebuggableAttribute((System.Diagnostics.DebuggableAttribute.DebuggingModes)(2))]
 [assembly:System.Reflection.AssemblyCompanyAttribute("Mono development team")]
 [assembly:System.Reflection.AssemblyCopyrightAttribute("(c) Various Mono authors")]
 [assembly:System.Reflection.AssemblyDefaultAliasAttribute("System.Data.Services.Client.dll")]
 [assembly:System.Reflection.AssemblyDescriptionAttribute("System.Data.Services.Client.dll")]
-[assembly:System.Reflection.AssemblyFileVersionAttribute("4.7.3062.0")]
-[assembly:System.Reflection.AssemblyInformationalVersionAttribute("4.7.3062.0")]
+[assembly:System.Reflection.AssemblyFileVersionAttribute("4.6.57.0")]
+[assembly:System.Reflection.AssemblyInformationalVersionAttribute("4.6.57.0")]
 [assembly:System.Reflection.AssemblyProductAttribute("Mono Common Language Infrastructure")]
 [assembly:System.Reflection.AssemblyTitleAttribute("System.Data.Services.Client.dll")]
 [assembly:System.Resources.NeutralResourcesLanguageAttribute("en-US")]
 [assembly:System.Resources.SatelliteContractVersionAttribute("4.0.0.0")]
-[assembly:System.Runtime.CompilerServices.CompilationRelaxationsAttribute(8)]
+[assembly:System.Runtime.CompilerServices.CompilationRelaxationsAttribute((System.Runtime.CompilerServices.CompilationRelaxations)(8))]
 [assembly:System.Runtime.CompilerServices.ReferenceAssemblyAttribute]
 [assembly:System.Runtime.CompilerServices.RuntimeCompatibilityAttribute(WrapNonExceptionThrows=true)]
 [assembly:System.Runtime.InteropServices.ComVisibleAttribute(false)]
-[assembly:System.Runtime.InteropServices.DefaultDllImportSearchPathsAttribute(System.Runtime.InteropServices.DllImportSearchPath.AssemblyDirectory | System.Runtime.InteropServices.DllImportSearchPath.System32)]
 [assembly:System.Security.AllowPartiallyTrustedCallersAttribute]
 [assembly:System.Security.SecurityCriticalAttribute]
-[assembly:System.Security.SecurityRulesAttribute(System.Security.SecurityRuleSet.Level1, SkipVerificationInFullTrust=true)]
+[assembly:System.Security.SecurityRulesAttribute((System.Security.SecurityRuleSet)(1), SkipVerificationInFullTrust=true)]
 namespace System.Data.Services.Client
 {
     public sealed partial class ChangeOperationResponse : System.Data.Services.Client.OperationResponse
@@ -42,7 +41,7 @@ namespace System.Data.Services.Client
         public DataServiceClientException(string message, int statusCode) { }
         public int StatusCode { get { throw null; } }
         [System.Security.SecurityCriticalAttribute]
-        [System.Security.Permissions.PermissionSetAttribute(System.Security.Permissions.SecurityAction.LinkDemand, Unrestricted=true)]
+        [System.Security.Permissions.SecurityPermissionAttribute(System.Security.Permissions.SecurityAction.Demand, SerializationFormatter=true)]
         public override void GetObjectData(System.Runtime.Serialization.SerializationInfo info, System.Runtime.Serialization.StreamingContext context) { }
     }
     public partial class DataServiceCollection<T> : System.Collections.ObjectModel.ObservableCollection<T>
@@ -127,8 +126,8 @@ namespace System.Data.Services.Client
         public void SetLink(object source, string sourceProperty, object target) { }
         public void SetSaveStream(object entity, System.IO.Stream stream, bool closeStream, System.Data.Services.Client.DataServiceRequestArgs args) { }
         public void SetSaveStream(object entity, System.IO.Stream stream, bool closeStream, string contentType, string slug) { }
-        public bool TryGetEntity<TEntity>(System.Uri identity, out TEntity entity) where TEntity : class { throw null; }
-        public bool TryGetUri(object entity, out System.Uri identity) { throw null; }
+        public bool TryGetEntity<TEntity>(System.Uri identity, out TEntity entity) where TEntity : class { entity = default(TEntity); throw null; }
+        public bool TryGetUri(object entity, out System.Uri identity) { identity = default(System.Uri); throw null; }
         public void UpdateObject(object entity) { }
     }
     public abstract partial class DataServiceQuery : System.Data.Services.Client.DataServiceRequest, System.Collections.IEnumerable, System.Linq.IQueryable
@@ -290,7 +289,7 @@ namespace System.Data.Services.Client
         public string SourceProperty { get { throw null; } }
         public object Target { get { throw null; } }
     }
-    [System.AttributeUsageAttribute(System.AttributeTargets.Class, AllowMultiple=false, Inherited=true)]
+    [System.AttributeUsageAttribute((System.AttributeTargets)(4), AllowMultiple=false, Inherited=true)]
     public sealed partial class MediaEntryAttribute : System.Attribute
     {
         public MediaEntryAttribute(string mediaMemberName) { }
@@ -303,7 +302,7 @@ namespace System.Data.Services.Client
         OverwriteChanges = 1,
         PreserveChanges = 2,
     }
-    [System.AttributeUsageAttribute(System.AttributeTargets.Class, AllowMultiple=false, Inherited=true)]
+    [System.AttributeUsageAttribute((System.AttributeTargets)(4), AllowMultiple=false, Inherited=true)]
     public sealed partial class MimeTypePropertyAttribute : System.Attribute
     {
         public MimeTypePropertyAttribute(string dataPropertyName, string mimeTypePropertyName) { }
@@ -362,12 +361,12 @@ namespace System.Data.Services.Client
 }
 namespace System.Data.Services.Common
 {
-    [System.AttributeUsageAttribute(System.AttributeTargets.Class, AllowMultiple=false)]
+    [System.AttributeUsageAttribute((System.AttributeTargets)(4), AllowMultiple=false)]
     public sealed partial class DataServiceEntityAttribute : System.Attribute
     {
         public DataServiceEntityAttribute() { }
     }
-    [System.AttributeUsageAttribute(System.AttributeTargets.Class, AllowMultiple=false)]
+    [System.AttributeUsageAttribute((System.AttributeTargets)(4), AllowMultiple=false)]
     public sealed partial class DataServiceKeyAttribute : System.Attribute
     {
         public DataServiceKeyAttribute(string keyName) { }
@@ -379,7 +378,7 @@ namespace System.Data.Services.Common
         V1 = 0,
         V2 = 1,
     }
-    [System.AttributeUsageAttribute(System.AttributeTargets.Class, AllowMultiple=true, Inherited=true)]
+    [System.AttributeUsageAttribute((System.AttributeTargets)(4), AllowMultiple=true, Inherited=true)]
     public sealed partial class EntityPropertyMappingAttribute : System.Attribute
     {
         public EntityPropertyMappingAttribute(string sourcePath, System.Data.Services.Common.SyndicationItemProperty targetSyndicationItem, System.Data.Services.Common.SyndicationTextContentKind targetTextContentKind, bool keepInContent) { }
@@ -392,13 +391,13 @@ namespace System.Data.Services.Common
         public System.Data.Services.Common.SyndicationItemProperty TargetSyndicationItem { get { throw null; } }
         public System.Data.Services.Common.SyndicationTextContentKind TargetTextContentKind { get { throw null; } }
     }
-    [System.AttributeUsageAttribute(System.AttributeTargets.Class, AllowMultiple=false)]
+    [System.AttributeUsageAttribute((System.AttributeTargets)(4), AllowMultiple=false)]
     public sealed partial class EntitySetAttribute : System.Attribute
     {
         public EntitySetAttribute(string entitySet) { }
         public string EntitySet { get { throw null; } }
     }
-    [System.AttributeUsageAttribute(System.AttributeTargets.Class, Inherited=true, AllowMultiple=false)]
+    [System.AttributeUsageAttribute((System.AttributeTargets)(4), Inherited=true, AllowMultiple=false)]
     public sealed partial class HasStreamAttribute : System.Attribute
     {
         public HasStreamAttribute() { }
