@@ -461,8 +461,8 @@ namespace System
             }
             
             // This is a flag to indicate if we are format the dates using Hebrew calendar.
-            bool isHebrewCalendar = ((CalendarId)cal.ID == CalendarId.HEBREW);
-            bool isJapaneseCalendar = ((CalendarId)cal.ID == CalendarId.JAPAN);
+            bool isHebrewCalendar = !GlobalizationMode.Invariant && ((CalendarId)cal.ID == CalendarId.HEBREW);
+            bool isJapaneseCalendar = !GlobalizationMode.Invariant && ((CalendarId)cal.ID == CalendarId.JAPAN);
             // This is a flag to indicate if we are formating hour/minute/second only.
             bool bTimeOnly = true;
 
@@ -584,7 +584,7 @@ namespace System
                         if (tokenLen <= 2)
                         {
                             int day = cal.GetDayOfMonth(dateTime);
-                            if (isHebrewCalendar)
+                            if (isHebrewCalendar && !GlobalizationMode.Invariant)
                             {
                                 // For Hebrew calendar, we need to convert numbers to Hebrew text for yyyy, MM, and dd values.
                                 HebrewFormatDigits(result, day);
@@ -612,7 +612,7 @@ namespace System
                         int month = cal.GetMonth(dateTime);
                         if (tokenLen <= 2)
                         {
-                            if (isHebrewCalendar)
+                            if (isHebrewCalendar && !GlobalizationMode.Invariant)
                             {
                                 // For Hebrew calendar, we need to convert numbers to Hebrew text for yyyy, MM, and dd values.
                                 HebrewFormatDigits(result, month);
@@ -624,7 +624,7 @@ namespace System
                         }
                         else
                         {
-                            if (isHebrewCalendar)
+                            if (isHebrewCalendar && !GlobalizationMode.Invariant)
                             {
                                 result.Append(FormatHebrewMonthName(dateTime, month, tokenLen, dtfi));
                             }
@@ -670,7 +670,7 @@ namespace System
                         {
                             FormatDigits(result, year, tokenLen <= 2 ? tokenLen : 2);
                         }
-                        else if ((CalendarId)cal.ID == CalendarId.HEBREW)
+                        else if (isHebrewCalendar && !GlobalizationMode.Invariant)
                         {
                             HebrewFormatDigits(result, year);
                         }
