@@ -17,10 +17,10 @@ namespace System.PrivateUri.Tests
     {
         // See RFC 3986 Section 5.2.2 and 5.4 http://www.ietf.org/rfc/rfc3986.txt
 
-        private readonly Uri _fullBaseUri = new Uri("http://user:psw@host:9090/path1/path2/path3/fileA?query#fragment");
-        private const string FullBaseUriGetLeftPart_Path = "http://user:psw@host:9090/path1/path2/path3/fileA";
-        private const string FullBaseUriGetLeftPart_Authority = "http://user:psw@host:9090";
-        private const string FullBaseUriGetLeftPart_Query = "http://user:psw@host:9090/path1/path2/path3/fileA?query";
+        private readonly Uri _fullBaseUri = new Uri("http://user:PLACEHOLDER@host:9090/path1/path2/path3/fileA?query#fragment");
+        private const string FullBaseUriGetLeftPart_Path = "http://user:PLACEHOLDER@host:9090/path1/path2/path3/fileA";
+        private const string FullBaseUriGetLeftPart_Authority = "http://user:PLACEHOLDER@host:9090";
+        private const string FullBaseUriGetLeftPart_Query = "http://user:PLACEHOLDER@host:9090/path1/path2/path3/fileA?query";
 
         [Fact]
         public void Uri_Relative_BaseVsAbsolute_ReturnsFullAbsolute()
@@ -535,7 +535,7 @@ namespace System.PrivateUri.Tests
         [Fact]
         public void Uri_Relative_BaseMadeRelativeToSamePath_ReturnsQueryAndFragment()
         {
-            Uri compareUri = new Uri("http://user:psw@host:9090/path1/path2/path3/fileA?AQuery#AFragment");
+            Uri compareUri = new Uri("http://user:PLACEHOLDER@host:9090/path1/path2/path3/fileA?AQuery#AFragment");
             Uri relative = _fullBaseUri.MakeRelativeUri(compareUri);
 
             String expectedResult = "?AQuery#AFragment"; // compareUri.GetParts(UriComponents.Query | UriComponents.Fragment,UriFormat.Unescaped);
@@ -545,7 +545,7 @@ namespace System.PrivateUri.Tests
         [Fact]
         public void Uri_Relative_BaseMadeRelativeToLastSlash_ReturnsDotSlashPlusQueryAndFragment()
         {
-            Uri compareUri = new Uri("http://user:psw@host:9090/path1/path2/path3/?AQuery#AFragment");
+            Uri compareUri = new Uri("http://user:PLACEHOLDER@host:9090/path1/path2/path3/?AQuery#AFragment");
             Uri relative = _fullBaseUri.MakeRelativeUri(compareUri);
             Uri reassembled = new Uri(_fullBaseUri, relative); // Symetric
 
@@ -558,7 +558,7 @@ namespace System.PrivateUri.Tests
         [Fact]
         public void Uri_Relative_BaseMadeRelativeToLastSlash_ReturnsDotSlash()
         {
-            Uri compareUri = new Uri("http://user:psw@host:9090/path1/path2/path3/");
+            Uri compareUri = new Uri("http://user:PLACEHOLDER@host:9090/path1/path2/path3/");
             Uri relative = _fullBaseUri.MakeRelativeUri(compareUri);
             Uri reassembled = new Uri(_fullBaseUri, relative); // Symetric
 
@@ -570,7 +570,7 @@ namespace System.PrivateUri.Tests
         [Fact]
         public void Uri_Relative_BaseMadeRelativeToLastSlashWithExtra_ReturnsDotSlashPlusQueryAndFragment()
         {
-            Uri compareUri = new Uri("http://user:psw@host:9090/path1/path2/path3/Path4/fileb?AQuery#AFragment");
+            Uri compareUri = new Uri("http://user:PLACEHOLDER@host:9090/path1/path2/path3/Path4/fileb?AQuery#AFragment");
             Uri relative = _fullBaseUri.MakeRelativeUri(compareUri);
             Uri reassembled = new Uri(_fullBaseUri, relative); // Symetric
 
@@ -582,7 +582,7 @@ namespace System.PrivateUri.Tests
         [Fact]
         public void Uri_Relative_BaseMadeRelativeToSecondToLastSlash_ReturnsDoubleDotSlashPlusQueryAndFragment()
         {
-            Uri compareUri = new Uri("http://user:psw@host:9090/path1/path2/?AQuery#AFragment");
+            Uri compareUri = new Uri("http://user:PLACEHOLDER@host:9090/path1/path2/?AQuery#AFragment");
             Uri relative = _fullBaseUri.MakeRelativeUri(compareUri);
             Uri reassembled = new Uri(_fullBaseUri, relative); // Symetric
 
@@ -594,7 +594,7 @@ namespace System.PrivateUri.Tests
         [Fact]
         public void Uri_Relative_BaseMadeRelativeToThirdToLastSlash_ReturnsDoubleDoubleDotSlashPlusQueryAndFragment()
         {
-            Uri compareUri = new Uri("http://user:psw@host:9090/path1/?AQuery#AFragment");
+            Uri compareUri = new Uri("http://user:PLACEHOLDER@host:9090/path1/?AQuery#AFragment");
             Uri relative = _fullBaseUri.MakeRelativeUri(compareUri);
             Uri reassembled = new Uri(_fullBaseUri, relative); // Symetric
 
@@ -606,7 +606,7 @@ namespace System.PrivateUri.Tests
         [Fact]
         public void Uri_Relative_BaseMadeRelativeToEmptyPath_ReturnsTrippleDoubleDotSlashPlusQueryAndFragment()
         {
-            Uri compareUri = new Uri("http://user:psw@host:9090/?AQuery#AFragment");
+            Uri compareUri = new Uri("http://user:PLACEHOLDER@host:9090/?AQuery#AFragment");
             Uri relative = _fullBaseUri.MakeRelativeUri(compareUri);
             Uri reassembled = new Uri(_fullBaseUri, relative); // Symetric
 
