@@ -609,6 +609,15 @@ public class Tests : TestsBase, ITest2
 		fixed_size_array();
 		test_new_exception_filter();
 		test_async_debug_generics();
+		if (args.Length >0 && args [0] == "pointer_arguments2") {
+			pointers2 ();
+			return 0;
+		}
+		if (args.Length >0 && args [0] == "ss_multi_thread") {
+			ss_multi_thread ();
+			return 0;
+		}
+		test_invalid_argument_assembly_get_type ();
 		return 3;
 	}
 
@@ -637,6 +646,10 @@ public class Tests : TestsBase, ITest2
 		LocalReflectClass.RunMe ();
 	}
 
+	public static void test_invalid_argument_assembly_get_type () {
+
+	}
+
 	public static void breakpoints () {
 		/* Call these early so it is JITted by the time a breakpoint is placed on it */
 		bp3 ();
@@ -857,6 +870,24 @@ public class Tests : TestsBase, ITest2
 		n.Buffer2 = new char4('a', 'b', 'c', 'd');
 	}
 
+	[MethodImplAttribute (MethodImplOptions.NoInlining)]
+	public static void ss_multi_thread () {
+		for (int i = 0; i < 5; i++)
+		{
+			var t = new Thread(mt_ss);
+			t.Name = "Thread_" + i;
+			t.Start();
+		}
+	}
+
+	[MethodImplAttribute (MethodImplOptions.NoInlining)]
+	static void mt_ss()
+	{
+		int a = 12;
+		int b = 13;
+		int c = 13;
+	}
+
 	[MethodImplAttribute (MethodImplOptions.NoInlining)]
 	public static void test_new_exception_filter () {
 		test_new_exception_filter1();
@@ -2232,6 +2263,17 @@ public class Tests : TestsBase, ITest2
 		rtMethod.Invoke(rtObject, new object[] { });
 	}
 	
+	public static unsafe void pointer_arguments2 (int* a) {
+		*a = 0;
+	}
+
+	[MethodImplAttribute (MethodImplOptions.NoInlining)]
+	public static unsafe void pointers2 () {
+		int[] a = new [] {1,2,3};
+		fixed (int* pa = a)
+			pointer_arguments2 (pa);
+	}
+
 	[MethodImplAttribute (MethodImplOptions.NoInlining)]
 	public static void new_thread_hybrid_exception() {
 		try
