@@ -1,4 +1,5 @@
 using System;
+using System.Threading;
 using System.Reflection;
 using System.Net.Http;
 
@@ -6,11 +7,18 @@ namespace MonoTests.System.Net.Http
 {
 	static class HttpClientTestHelpers
 	{
-#if LEGACY_HTTPCLIENT
-		internal static bool UsingSocketsHandler => false;
-#else
-		internal static bool UsingSocketsHandler => true;
-#endif
+		static bool initialized;
+		static bool usingSocketsHandler;
+		static object syncLock;
+
+		internal static bool UsingSocketsHandler {
+			get {
+				LazyInitializer.EnsureInitialized (
+					ref usingSocketsHandler, ref initialized, ref syncLock,
+					() => typeof (HttpClient).Assembly.GetType ("System.Net.Http.SocketsHttpHandler") != null);
+				return usingSocketsHandler;
+			}
+		}
 
 		internal static bool IsSocketsHandler (HttpClientHandler handler) => UsingSocketsHandler;
 
