@@ -189,7 +189,9 @@ namespace MonoTests.System.Net.Http
 
 		[Test]
 #if FEATURE_NO_BSD_SOCKETS
+#if !MONOTOUCH_WATCH			
 		[ExpectedException (typeof (PlatformNotSupportedException))]
+#endif		
 #endif
 		public void Ctor_HttpClientHandler ()
 		{
@@ -339,6 +341,7 @@ namespace MonoTests.System.Net.Http
 #if FEATURE_NO_BSD_SOCKETS
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #endif
+		[Category ("InetAccess")]
 		public void Proxy_Disabled ()
 		{
 			var pp = WebRequest.DefaultWebProxy;
@@ -1109,7 +1112,9 @@ namespace MonoTests.System.Net.Http
 
 		[Test]
 #if FEATURE_NO_BSD_SOCKETS
+#if !MONOTOUCH_WATCH			
 		[ExpectedException (typeof (PlatformNotSupportedException))]
+#endif		
 #endif
 		public void Send_Invalid ()
 		{
