@@ -145,7 +145,10 @@ namespace System.IO.Compression
 
 		internal int ReadCore (Span<byte> destination)
 		{
-			throw new NotImplementedException ();
+			var buffer = new byte [destination.Length];
+			int count = Read(buffer, 0, buffer.Length);
+			buffer.AsSpan(0, count).CopyTo(destination);
+			return count;
 		}
 
 		public override int Read (byte[] array, int offset, int count)
@@ -185,7 +188,7 @@ namespace System.IO.Compression
 
 		internal void WriteCore (ReadOnlySpan<byte> source)
 		{
-			throw new NotImplementedException ();
+			Write (source.ToArray (), 0, source.Length);
 		}
 
 		public override void Write (byte[] array, int offset, int count)
@@ -554,7 +557,7 @@ namespace System.IO.Compression
 		{
 			throw new PlatformNotSupportedException ();
 		}
-#elif MONOTOUCH || MONODROID
+#elif MONOTOUCH || MONODROID || WASM
 		[MethodImplAttribute(MethodImplOptions.InternalCall)]
 		static extern IntPtr CreateZStream (int compress, bool gzip, IntPtr feeder, IntPtr data);
 
