@@ -39,7 +39,7 @@ namespace MonoTests.System.Net {
 	[TestFixture]
 	public class HttpListenerTest {
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #endif
 		public void DefaultProperties ()
@@ -55,7 +55,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #endif
 		public void Start1 ()
@@ -65,7 +65,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #endif
 		public void Stop1 ()
@@ -75,7 +75,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #else
 		[ExpectedException (typeof (InvalidOperationException))]
@@ -88,7 +88,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #else
 		[ExpectedException (typeof (InvalidOperationException))]
@@ -102,7 +102,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #else
 		[ExpectedException (typeof (InvalidOperationException))]
@@ -115,7 +115,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #endif
 		public void BeginGetContext2 ()
@@ -227,7 +227,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #endif
 		public void CloseBeforeStart ()
@@ -271,7 +271,7 @@ namespace MonoTests.System.Net {
 		}
 		
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #endif
 		public void AbortBeforeStart ()
@@ -292,7 +292,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #endif
 		public void PropertiesWhenClosed1 ()
@@ -308,7 +308,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #else
 		[ExpectedException (typeof (ObjectDisposedException))]
@@ -321,7 +321,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #else
 		[ExpectedException (typeof (ObjectDisposedException))]
@@ -334,7 +334,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #else
 		[ExpectedException (typeof (ObjectDisposedException))]
@@ -347,7 +347,8 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+		[Category ("NotWasm")]
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #else
 		[ExpectedException (typeof (ObjectDisposedException))]
@@ -360,7 +361,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #else
 		[ExpectedException (typeof (ObjectDisposedException))]
@@ -373,7 +374,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #else
 		[ExpectedException (typeof (ObjectDisposedException))]
@@ -386,7 +387,7 @@ namespace MonoTests.System.Net {
 		}
 
 		[Test]
-#if FEATURE_NO_BSD_SOCKETS
+#if FEATURE_NO_BSD_SOCKETS && !WASM
 		[ExpectedException (typeof (PlatformNotSupportedException))]
 #endif
 		public void PropertiesWhenClosed3 ()
