@@ -26,4 +26,7 @@ partial class SR
 	public const string Arg_SwitchExpressionException = "Non-exhaustive switch expression failed to match its input.";
 	public const string SwitchExpressionException_UnmatchedValue = "Unmatched value was {0}.";
 	public const string Argument_InvalidRandomRange = "Range of random number does not contain at least one possibility.";
+	public const string BufferWriterAdvancedTooFar = "Cannot advance past the end of the buffer, which has a size of {0}.";
+	public const string net_gssapi_operation_failed_detailed_majoronly = "GSSAPI operation failed with error - {0}.";
+	public const string net_gssapi_operation_failed_majoronly = "SSAPI operation failed with status: {0}.";
 }
\ No newline at end of file
