@@ -319,7 +319,7 @@ dump_processor_state (SgenBridgeProcessor *p)
 		printf ("\tSCC %d:", i);
 		for (j = 0; j < scc->num_objs; ++j) {
 			MonoObject *obj = scc->objs [j];
-			printf (" %p", obj);
+			printf (" %p(%s)", obj, SGEN_LOAD_VTABLE (obj)->klass->name);
 		}
 		printf ("\n");
 	}
@@ -516,7 +516,8 @@ static const char *bridge_class;
 static MonoGCBridgeObjectKind
 bridge_test_bridge_class_kind (MonoClass *klass)
 {
-	if (!strcmp (bridge_class, m_class_get_name (klass)))
+	if (!strcmp (bridge_class, m_class_get_name (klass)) ||
+			(m_class_get_parent (klass) && !strcmp (bridge_class, m_class_get_name (m_class_get_parent (klass)))))
 		return GC_BRIDGE_TRANSPARENT_BRIDGE_CLASS;
 	return GC_BRIDGE_TRANSPARENT_CLASS;
 }
@@ -708,6 +709,7 @@ sgen_bridge_handle_gc_debug (const char *opt)
 		if (selection != BRIDGE_PROCESSOR_INVALID) {
 			// Compare processor doesn't get config
 			init_bridge_processor (&compare_to_bridge_processor, selection);
+			bridge_processor_config.disable_non_bridge_scc = TRUE;
 		} else {
 			g_warning ("Invalid bridge implementation to compare against - ignoring.");
 		}
