@@ -1092,4 +1092,10 @@ sgen_new_bridge_init (SgenBridgeProcessor *collector)
 	bridge_processor = collector;
 }
 
+#else
+
+#include <mono/utils/mono-compiler.h>
+
+MONO_EMPTY_SOURCE_FILE (sgen_new_bridge);
+
 #endif
