@@ -14,6 +14,8 @@
 #include <config.h>
 #include <glib.h>
 
+#ifndef ENABLE_NETCORE
+
 #include <mono/metadata/threadpool.h>
 #include <mono/metadata/threadpool-worker.h>
 
@@ -76,14 +78,4 @@ mono_threadpool_worker_notify_completed (void)
 	return FALSE;
 }
 
-#ifdef ENABLE_NETCORE
-gint64 mono_threadpool_worker_get_completed_threads_count (void)
-{
-	return 0;
-}
-
-gint32 mono_threadpool_worker_get_threads_count (void)
-{
-	return 0;
-}
 #endif
