@@ -163,8 +163,6 @@ cleanup (void)
 gboolean
 mono_threadpool_enqueue_work_item (MonoDomain *domain, MonoObject *work_item, MonoError *error)
 {
-	static MonoClass *threadpool_class = NULL;
-	static MonoMethod *unsafe_queue_custom_work_item_method = NULL;
 	MonoDomain *current_domain;
 	MonoBoolean f;
 	gpointer args [2];
@@ -172,13 +170,19 @@ mono_threadpool_enqueue_work_item (MonoDomain *domain, MonoObject *work_item, Mo
 	error_init (error);
 	g_assert (work_item);
 
-	if (!threadpool_class)
+	MONO_STATIC_POINTER_INIT (MonoClass, threadpool_class)
+
 		threadpool_class = mono_class_load_from_name (mono_defaults.corlib, "System.Threading", "ThreadPool");
 
-	if (!unsafe_queue_custom_work_item_method) {
+	MONO_STATIC_POINTER_INIT_END (MonoClass, threadpool_class)
+
+	MONO_STATIC_POINTER_INIT (MonoMethod, unsafe_queue_custom_work_item_method)
+
 		unsafe_queue_custom_work_item_method = mono_class_get_method_from_name_checked (threadpool_class, "UnsafeQueueCustomWorkItem", 2, 0, error);
 		mono_error_assert_ok (error);
-	}
+
+	MONO_STATIC_POINTER_INIT_END (MonoMethod, unsafe_queue_custom_work_item_method)
+
 	g_assert (unsafe_queue_custom_work_item_method);
 
 	f = FALSE;
@@ -289,10 +293,13 @@ try_invoke_perform_wait_callback (MonoObject** exc, MonoError *error)
 	HANDLE_FUNCTION_RETURN_VAL (res);
 }
 
-static gsize
-set_thread_name (MonoInternalThread *thread)
+static void
+mono_threadpool_set_thread_name (MonoInternalThread *thread)
 {
-	return mono_thread_set_name_constant_ignore_error (thread, "Thread Pool Worker", MonoSetThreadNameFlag_Reset);
+	mono_thread_set_name_constant_ignore_error (
+		thread,
+		"Thread Pool Worker",
+		MonoSetThreadNameFlag_Reset | MonoSetThreadNameFlag_RepeatedlyButOptimized);
 }
 
 static void
@@ -330,10 +337,8 @@ worker_callback (void)
 	 */
 	mono_defaults.threadpool_perform_wait_callback_method->save_lmf = TRUE;
 
-	gsize name_generation = thread->name.generation;
 	/* Set the name if this is the first call to worker_callback on this thread */
-	if (name_generation == 0)
-	   name_generation = set_thread_name (thread);
+	mono_threadpool_set_thread_name (thread);
 
 	domains_lock ();
 
@@ -366,13 +371,7 @@ worker_callback (void)
 
 		domains_unlock ();
 
-		// Any thread can set any other thread name at any time.
-		// So this is unavoidably racy.
-		// This only partly fights against that -- i.e. not atomic and not a loop.
-		// It is reliable against the thread setting its own name, and somewhat
-		// reliable against other threads setting this thread's name.
-		if (name_generation != thread->name.generation)
-			name_generation = set_thread_name (thread);
+		mono_threadpool_set_thread_name (thread);
 
 		mono_thread_clear_and_set_state (thread,
 			(MonoThreadState)~ThreadState_Background,
@@ -400,8 +399,7 @@ worker_callback (void)
 		mono_thread_pop_appdomain_ref ();
 
 		/* Reset name after every callback */
-		if (name_generation != thread->name.generation)
-			name_generation = set_thread_name (thread);
+		mono_threadpool_set_thread_name (thread);
 
 		domains_lock ();
 
@@ -445,16 +443,18 @@ mono_threadpool_cleanup (void)
 MonoAsyncResult *
 mono_threadpool_begin_invoke (MonoDomain *domain, MonoObject *target, MonoMethod *method, gpointer *params, MonoError *error)
 {
-	static MonoClass *async_call_klass = NULL;
 	MonoMethodMessage *message;
 	MonoAsyncResult *async_result;
 	MonoAsyncCall *async_call;
 	MonoDelegate *async_callback = NULL;
 	MonoObject *state = NULL;
 
-	if (!async_call_klass)
+	MONO_STATIC_POINTER_INIT (MonoClass, async_call_klass)
+
 		async_call_klass = mono_class_load_from_name (mono_defaults.corlib, "System", "MonoAsyncCall");
 
+	MONO_STATIC_POINTER_INIT_END (MonoClass, async_call_klass)
+
 	error_init (error);
 
 	message = mono_method_call_message_new (method, params, mono_get_delegate_invoke_internal (method->klass), (params != NULL) ? (&async_callback) : NULL, (params != NULL) ? (&state) : NULL, error);
