@@ -259,9 +259,9 @@ mono_constant_fold_ins (MonoCompile *cfg, MonoInst *ins, MonoInst *arg1, MonoIns
 		break;
 	case OP_SEXT_I4:
 		if (arg1->opcode == OP_ICONST && arg1->inst_c0 >= 0 && arg1->inst_c0 < (1 << 16) && overwrite) {
-			dest->opcode = OP_ICONST;
+			dest->opcode = OP_I8CONST;
 			dest->sreg1 = -1;
-			dest->inst_c0 = arg1->inst_c0;
+			dest->inst_l = arg1->inst_c0;
 		}
 		break;
 	case OP_MOVE:
