@@ -280,15 +280,16 @@ mono_parse_default_optimizations (const char* p)
 char*
 mono_opt_descr (guint32 flags) {
 	GString *str = g_string_new ("");
-	int i, need_comma;
+	int i;
+	gboolean need_comma;
 
-	need_comma = 0;
+	need_comma = FALSE;
 	for (i = 0; i < G_N_ELEMENTS (opt_names); ++i) {
 		if (flags & (1 << i) && optflag_get_name (i)) {
 			if (need_comma)
 				g_string_append_c (str, ',');
 			g_string_append (str, optflag_get_name (i));
-			need_comma = 1;
+			need_comma = TRUE;
 		}
 	}
 	return g_string_free (str, FALSE);
@@ -326,6 +327,51 @@ opt_sets [] = {
        DEFAULT_OPTIMIZATIONS, 
 };
 
+static const guint32
+interp_opt_sets [] = {
+	INTERP_OPT_NONE,
+	INTERP_OPT_INLINE,
+	INTERP_OPT_CPROP,
+	INTERP_OPT_SUPER_INSTRUCTIONS,
+	INTERP_OPT_INLINE | INTERP_OPT_CPROP,
+	INTERP_OPT_INLINE | INTERP_OPT_SUPER_INSTRUCTIONS,
+	INTERP_OPT_CPROP | INTERP_OPT_SUPER_INSTRUCTIONS,
+	INTERP_OPT_INLINE | INTERP_OPT_CPROP | INTERP_OPT_SUPER_INSTRUCTIONS,
+};
+
+static const char* const
+interp_opflags_names [] = {
+	"inline",
+	"cprop",
+	"super-insn"
+};
+
+static const char*
+interp_optflag_get_name (guint32 i)
+{
+	g_assert (i < G_N_ELEMENTS (interp_opflags_names));
+	return interp_opflags_names [i];
+}
+
+static char*
+interp_opt_descr (guint32 flags)
+{
+	GString *str = g_string_new ("");
+	int i;
+	gboolean need_comma;
+
+	need_comma = FALSE;
+	for (i = 0; i < G_N_ELEMENTS (interp_opflags_names); ++i) {
+		if (flags & (1 << i) && interp_optflag_get_name (i)) {
+			if (need_comma)
+				g_string_append_c (str, ',');
+			g_string_append (str, interp_optflag_get_name (i));
+			need_comma = TRUE;
+		}
+	}
+	return g_string_free (str, FALSE);
+}
+
 typedef int (*TestMethod) (void);
 
 #if 0
@@ -685,7 +731,7 @@ mini_regression_list (int verbose, int count, char *images [])
 }
 
 static void
-interp_regression_step (MonoImage *image, int verbose, int *total_run, int *total, GTimer *timer, MonoDomain *domain)
+interp_regression_step (MonoImage *image, int verbose, int *total_run, int *total, const guint32 *opt_flags, GTimer *timer, MonoDomain *domain)
 {
 	int result, expected, failed, cfailed, run;
 	double elapsed, transform_time;
@@ -693,10 +739,20 @@ interp_regression_step (MonoImage *image, int verbose, int *total_run, int *tota
 	MonoObject *result_obj;
 	int local_skip_index = 0;
 
-	g_print ("Test run: image=%s\n", mono_image_get_filename (image));
+	const char *n = NULL;
+	if (opt_flags) {
+		mini_get_interp_callbacks ()->set_optimizations (*opt_flags);
+		n = interp_opt_descr (*opt_flags);
+	} else {
+		n = mono_interp_opts_string;
+	}
+	g_print ("Test run: image=%s, opts=%s\n", mono_image_get_filename (image), n);
+
 	cfailed = failed = run = 0;
 	transform_time = elapsed = 0.0;
 
+	mini_get_interp_callbacks ()->invalidate_transformed (domain);
+
 	g_timer_start (timer);
 	for (i = 0; i < mono_image_get_table_rows (image, MONO_TABLE_METHOD); ++i) {
 		ERROR_DECL (error);
@@ -723,7 +779,7 @@ interp_regression_step (MonoImage *image, int verbose, int *total_run, int *tota
 				cfailed++;
 				g_print ("Test '%s' execution failed.\n", method->name);
 			} else if (exc != NULL) {
-				g_print ("Exception in Test '%s' occured:\n", method->name);
+				g_print ("Exception in Test '%s' occurred:\n", method->name);
 				mono_object_describe (exc);
 				run++;
 				failed++;
@@ -776,7 +832,14 @@ interp_regression (MonoImage *image, int verbose, int *total_run)
 
 	total = 0;
 	*total_run = 0;
-	interp_regression_step (image, verbose, total_run, &total, timer, domain);
+
+	if (mono_interp_opts_string) {
+		/* explicit option requested*/
+		interp_regression_step (image, verbose, total_run, &total, NULL, timer, domain);
+	} else {
+		for (int opt = 0; opt < G_N_ELEMENTS (interp_opt_sets); ++opt)
+			interp_regression_step (image, verbose, total_run, &total, &interp_opt_sets [opt], timer, domain);
+	}
 
 	g_timer_destroy (timer);
 	return total;
@@ -1689,6 +1752,29 @@ mono_get_version_info (void)
 
 static gboolean enable_debugging;
 
+static void
+enable_runtime_stats (void)
+{
+	mono_counters_enable (-1);
+	mono_atomic_store_bool (&mono_stats.enabled, TRUE);
+	mono_atomic_store_bool (&mono_jit_stats.enabled, TRUE);
+}
+
+static MonoMethodDesc *
+parse_qualified_method_name (char *method_name)
+{
+	if (strlen (method_name) == 0) {
+		g_printerr ("Couldn't parse empty method name.");
+		exit (1);
+	}
+	MonoMethodDesc *result = mono_method_desc_new (method_name, TRUE);
+	if (!result) {
+		g_printerr ("Couldn't parse method name: %s\n", method_name);
+		exit (1);
+	}
+	return result;
+}
+
 /**
  * mono_jit_parse_options:
  *
@@ -1714,7 +1800,7 @@ mono_jit_parse_options (int argc, char * argv[])
 	for (i = 0; i < argc; ++i) {
 		if (argv [i] [0] != '-')
 			break;
- 		if (strncmp (argv [i], "--debugger-agent=", 17) == 0) {
+		if (strncmp (argv [i], "--debugger-agent=", 17) == 0) {
 			MonoDebugOptions *opt = mini_get_debug_options ();
 
 			sdb_options = g_strdup (argv [i] + 17);
@@ -1742,9 +1828,12 @@ mono_jit_parse_options (int argc, char * argv[])
 
 			opt->break_on_exc = TRUE;
 		} else if (strcmp (argv [i], "--stats") == 0) {
-			mono_counters_enable (-1);
-			mono_atomic_store_bool (&mono_stats.enabled, TRUE);
-			mono_atomic_store_bool (&mono_jit_stats.enabled, TRUE);
+			enable_runtime_stats ();
+		} else if (strncmp (argv [i], "--stats=", 8) == 0) {
+			enable_runtime_stats ();
+			if (mono_stats_method_desc)
+				g_free (mono_stats_method_desc);
+			mono_stats_method_desc = parse_qualified_method_name (argv [i] + 8);
 		} else if (strcmp (argv [i], "--break") == 0) {
 			if (i+1 >= argc){
 				fprintf (stderr, "Missing method name in --break command line option\n");
@@ -2187,9 +2276,12 @@ mono_main (int argc, char* argv[])
 		} else if (strcmp (argv [i], "--print-vtable") == 0) {
 			mono_print_vtable = TRUE;
 		} else if (strcmp (argv [i], "--stats") == 0) {
-			mono_counters_enable (-1);
-			mono_atomic_store_bool (&mono_stats.enabled, TRUE);
-			mono_atomic_store_bool (&mono_jit_stats.enabled, TRUE);
+			enable_runtime_stats ();
+		} else if (strncmp (argv [i], "--stats=", 8) == 0) {
+			enable_runtime_stats ();
+			if (mono_stats_method_desc)
+				g_free (mono_stats_method_desc);
+			mono_stats_method_desc = parse_qualified_method_name (argv [i] + 8);
 #ifndef DISABLE_AOT
 		} else if (strcmp (argv [i], "--aot") == 0) {
 			error_if_aot_unsupported ();
@@ -2362,9 +2454,9 @@ mono_main (int argc, char* argv[])
 		} else if (strncmp (argv [i], "--assembly-loader=", strlen("--assembly-loader=")) == 0) {
 			gchar *arg = argv [i] + strlen ("--assembly-loader=");
 			if (strcmp (arg, "strict") == 0)
-				mono_loader_set_strict_strong_names (TRUE);
+				mono_loader_set_strict_assembly_name_check (TRUE);
 			else if (strcmp (arg, "legacy") == 0)
-				mono_loader_set_strict_strong_names (FALSE);
+				mono_loader_set_strict_assembly_name_check (FALSE);
 			else
 				fprintf (stderr, "Warning: unknown argument to --assembly-loader. Should be \"strict\" or \"legacy\"\n");
 		} else if (strncmp (argv [i], MONO_HANDLERS_ARGUMENT, MONO_HANDLERS_ARGUMENT_LEN) == 0) {
