@@ -97,7 +97,7 @@
 #elif defined(TARGET_ASM_GAS) && defined(TARGET_WIN32)
 #define AS_INT16_DIRECTIVE ".word"
 #elif defined(TARGET_ASM_GAS)
-#define AS_INT16_DIRECTIVE ".hword"
+#define AS_INT16_DIRECTIVE ".short"
 #else
 #define AS_INT16_DIRECTIVE ".word"
 #endif
@@ -410,11 +410,14 @@ create_reloc (MonoImageWriter *acfg, const char *end, const char* start, int off
 	BinReloc *reloc;
 	reloc = (BinReloc *)mono_mempool_alloc0 (acfg->mempool, sizeof (BinReloc));
 	reloc->val1 = mono_mempool_strdup (acfg->mempool, end);
-	if (strcmp (start, ".") == 0) {
-		reloc->val2_section = acfg->cur_section;
-		reloc->val2_offset = acfg->cur_section->cur_offset;
-	} else {
-		reloc->val2 = mono_mempool_strdup (acfg->mempool, start);
+	if (start)
+	{
+		if (strcmp (start, ".") == 0) {
+			reloc->val2_section = acfg->cur_section;
+			reloc->val2_offset = acfg->cur_section->cur_offset;
+		} else {
+			reloc->val2 = mono_mempool_strdup (acfg->mempool, start);
+		}
 	}
 	reloc->offset = offset;
 	reloc->section = acfg->cur_section;
@@ -424,6 +427,13 @@ create_reloc (MonoImageWriter *acfg, const char *end, const char* start, int off
 	return reloc;
 }
 
+static void
+bin_writer_emit_symbol (MonoImageWriter *acfg, const char *symbol)
+{
+	create_reloc (acfg, symbol, NULL, 0);
+	acfg->cur_section->cur_offset += 4;
+}
+
 static void
 bin_writer_emit_symbol_diff (MonoImageWriter *acfg, const char *end, const char* start, int offset)
 {
@@ -1924,6 +1934,23 @@ asm_writer_emit_int32 (MonoImageWriter *acfg, int value)
 	fprintf (acfg->fp, "%d", value);
 }
 
+static void
+asm_writer_emit_symbol (MonoImageWriter *acfg, const char *symbol)
+{
+	if (acfg->mode != EMIT_LONG) {
+		acfg->mode = EMIT_LONG;
+		acfg->col_count = 0;
+	}
+
+	symbol = get_label (symbol);
+
+	if ((acfg->col_count++ % 8) == 0)
+		fprintf (acfg->fp, "\n\t%s ", AS_INT32_DIRECTIVE);
+	else
+		fprintf (acfg->fp, ",");
+	fprintf (acfg->fp, "%s", symbol);
+}
+
 static void
 asm_writer_emit_symbol_diff (MonoImageWriter *acfg, const char *end, const char* start, int offset)
 {
@@ -2213,6 +2240,19 @@ mono_img_writer_emit_int32 (MonoImageWriter *acfg, int value)
 #endif
 }
 
+void
+mono_img_writer_emit_symbol (MonoImageWriter *acfg, const char *symbol)
+{
+#ifdef USE_BIN_WRITER
+	if (acfg->use_bin_writer)
+		bin_writer_emit_symbol (acfg, symbol);
+	else
+		asm_writer_emit_symbol (acfg, symbol);
+#else
+	asm_writer_emit_symbol (acfg, symbol);
+#endif
+}
+
 void
 mono_img_writer_emit_symbol_diff (MonoImageWriter *acfg, const char *end, const char* start, int offset)
 {
