@@ -26,6 +26,14 @@ struct _InterpMethodArguments {
 #endif
 };
 
+enum {
+	INTERP_OPT_NONE = 0,
+	INTERP_OPT_INLINE = 1,
+	INTERP_OPT_CPROP = 2,
+	INTERP_OPT_SUPER_INSTRUCTIONS = 4,
+	INTERP_OPT_DEFAULT = INTERP_OPT_INLINE | INTERP_OPT_CPROP | INTERP_OPT_SUPER_INSTRUCTIONS
+};
+
 typedef struct _InterpMethodArguments InterpMethodArguments;
 
 /* must be called either
