@@ -153,7 +153,7 @@ tls_get_restore_state (void *tls)
 }
 
 static gboolean
-try_process_suspend (void *tls, MonoContext *ctx)
+try_process_suspend (void *tls, MonoContext *ctx, gboolean from_breakpoint)
 {
 	return FALSE;
 }
@@ -239,7 +239,7 @@ process_breakpoint_events (void *_evts, MonoMethod *method, MonoContext *ctx, in
 	BpEvents *evts = (BpEvents*)_evts;
 	if (evts) {
 		if (evts->is_ss)
-			mono_de_cancel_ss ();
+			mono_de_cancel_all_ss ();
 		mono_wasm_fire_bp ();
 		g_free (evts);
 	}
@@ -291,6 +291,12 @@ ss_args_destroy (SingleStepArgs *ss_args)
 	//nothing to do	
 }
 
+static int
+handle_multiple_ss_requests (void) {
+	mono_de_cancel_all_ss ();
+	return 1;
+}
+
 void
 mono_wasm_debugger_init (void)
 {
@@ -313,6 +319,7 @@ mono_wasm_debugger_init (void)
 		.process_breakpoint_events = process_breakpoint_events,
 		.ss_create_init_args = ss_create_init_args,
 		.ss_args_destroy = ss_args_destroy,
+		.handle_multiple_ss_requests = handle_multiple_ss_requests,
 	};
 
 	mono_debug_init (MONO_DEBUG_FORMAT_MONO);
@@ -371,14 +378,14 @@ mono_wasm_setup_single_step (int kind)
 		depth = STEP_DEPTH_OVER;
 		break;
 	default:
-		g_error ("dunno step kind %d", kind);
+		g_error ("[dbg] unknown step kind %d", kind);
 	}
 
 	DbgEngineErrorCode err = mono_de_ss_create (THREAD_TO_INTERNAL (mono_thread_current ()), size, depth, filter, req);
 	if (err != DE_ERR_NONE) {
 		DEBUG_PRINTF (1, "[dbg] Failed to setup single step request");
 	}
-	printf ("ss is in place, now ahat?\n");
+	DEBUG_PRINTF (1, "[dbg] single step is in place, now what?\n");
 }
 
 EMSCRIPTEN_KEEPALIVE void
@@ -648,11 +655,11 @@ static gboolean describe_value(MonoType * type, gpointer addr)
 			} else {
 				GString *class_name;
 				class_name = g_string_new ("");
-				if (*(obj->vtable->klass->name_space)) {
-					g_string_append (class_name, obj->vtable->klass->name_space);
+				if (*(m_class_get_name_space (obj->vtable->klass))) {
+					g_string_append (class_name, m_class_get_name_space (obj->vtable->klass));
 					g_string_append_c (class_name, '.');
 				}
-				g_string_append (class_name, obj->vtable->klass->name);
+				g_string_append (class_name, m_class_get_name (obj->vtable->klass));
 				if (m_class_get_byval_arg (obj->vtable->klass)->type == MONO_TYPE_SZARRAY || m_class_get_byval_arg (obj->vtable->klass)->type == MONO_TYPE_ARRAY)
 					mono_wasm_add_array_var (class_name->str, get_object_id(obj));
 				else
@@ -814,11 +821,11 @@ describe_this (MonoStackFrameInfo *info, MonoContext *ctx, gpointer ud)
 		mono_wasm_add_properties_var("this");
 		GString *class_name;
 		class_name = g_string_new ("");
-		if (*(obj->vtable->klass->name_space)) {
-			g_string_append (class_name, obj->vtable->klass->name_space);
+		if (*(m_class_get_name_space (obj->vtable->klass))) {
+			g_string_append (class_name, m_class_get_name_space (obj->vtable->klass));
 			g_string_append_c (class_name, '.');
 		}
-		g_string_append (class_name, obj->vtable->klass->name);
+		g_string_append (class_name, m_class_get_name (obj->vtable->klass));
 		mono_wasm_add_obj_var (class_name->str, get_object_id(obj));
 		g_string_free(class_name, FALSE);
 	}
