@@ -441,12 +441,6 @@ mono_arch_flush_register_windows (void)
 {
 }
 
-void
-mono_arch_free_jit_tls_data (MonoJitTlsData *tls)
-{
-}
-
-
 MonoMethod*
 mono_arch_find_imt_method (host_mgreg_t *regs, guint8 *code)
 {
@@ -638,12 +632,13 @@ G_BEGIN_DECLS
 #include <pwd.h>
 #include <uuid/uuid.h>
 
-//libc / libpthread missing bits from musl or shit we didn't detect :facepalm:
+#ifndef __EMSCRIPTEN_PTHREADS__
 int pthread_getschedparam (pthread_t thread, int *policy, struct sched_param *param)
 {
 	g_error ("pthread_getschedparam");
 	return 0;
 }
+#endif
 
 int
 pthread_setschedparam(pthread_t thread, int policy, const struct sched_param *param)
@@ -651,13 +646,6 @@ pthread_setschedparam(pthread_t thread, int policy, const struct sched_param *pa
 	return 0;
 }
 
-
-int
-pthread_attr_getstacksize (const pthread_attr_t *attr, size_t *stacksize)
-{
-	return 65536; //wasm page size
-}
-
 int
 pthread_sigmask (int how, const sigset_t *set, sigset_t *oset)
 {
@@ -710,13 +698,14 @@ inotify_add_watch (int fd, const char *pathname, uint32_t mask)
 	return 0;
 }
 
+#ifndef __EMSCRIPTEN_PTHREADS__
 int
 sem_timedwait (sem_t *sem, const struct timespec *abs_timeout)
 {
 	g_error ("sem_timedwait");
 	return 0;
-	
 }
+#endif
 
 ssize_t sendfile(int out_fd, int in_fd, off_t *offset, size_t count);
 
