@@ -54,8 +54,6 @@ PATCH_INFO(AOT_JIT_INFO, "aot_jit_info")
 PATCH_INFO(GC_NURSERY_BITS, "gc_nursery_bits")
 PATCH_INFO(GSHAREDVT_IN_WRAPPER, "gsharedvt_in_wrapper")
 PATCH_INFO(ICALL_ADDR_CALL, "icall_addr_call")
-PATCH_INFO(GET_TLS_TRAMP, "get_tls_tramp")
-PATCH_INFO(SET_TLS_TRAMP, "set_tls_tramp")
 /*
  * The address of a C function implementing a JIT icall.
  * Same as JIT_ICALL_ADDR, but not treated as a call.
@@ -70,5 +68,4 @@ PATCH_INFO(PROFILER_CLAUSE_COUNT, "profiler_clause_count")
  */
 PATCH_INFO(METHOD_FTNDESC, "method_ftndesc")
 
-PATCH_INFO(TRAMPOLINE_FUNC_ADDR, "trampoline_func_addr")
 PATCH_INFO(SPECIFIC_TRAMPOLINE_LAZY_FETCH_ADDR, "specific_trampoline_lazy_fetch_addr")
