@@ -6,12 +6,15 @@
 #define __MONO_TRACE_H__
 #include <glib.h>
 #include "mono/utils/mono-compiler.h"
+#include "mono/metadata/icalls.h"
 
+ICALL_EXTERN_C
 void
-mono_trace_enter_method (MonoMethod *method, MonoProfilerCallContext *ctx);
+mono_trace_enter_method (MonoMethod *method, MonoJitInfo *ji, MonoProfilerCallContext *ctx);
 
+ICALL_EXTERN_C
 void 
-mono_trace_leave_method (MonoMethod *method, MonoProfilerCallContext *ctx);
+mono_trace_leave_method (MonoMethod *method, MonoJitInfo *ji, MonoProfilerCallContext *ctx);
 
 void mono_trace_enable (gboolean enable);
 gboolean mono_trace_is_enabled (void);
