@@ -77,6 +77,7 @@
 #include <mono/utils/mono-os-mutex.h>
 #include <mono/utils/mono-logger-internals.h>
 #include <mono/utils/mono-counters.h>
+#include <mono/utils/mono-publib.h>
 
 // Statistics for profiler events.
 static gint32 coverage_methods_ctr,
@@ -690,6 +691,9 @@ coverage_filter (MonoProfiler *prof, MonoMethod *method)
 {
 	guint32 iflags, flags;
 
+	if (method->wrapper_type)
+		return FALSE;
+
 	flags = mono_method_get_flags (method, &iflags);
 
 	if ((iflags & METHOD_IMPL_ATTRIBUTE_INTERNAL_CALL) ||
