@@ -74,5 +74,8 @@ MONO_HWCAP_VAR(x86_has_ssse3)
 MONO_HWCAP_VAR(x86_has_sse41)
 MONO_HWCAP_VAR(x86_has_sse42)
 MONO_HWCAP_VAR(x86_has_sse4a)
+MONO_HWCAP_VAR(x86_has_lzcnt)
+MONO_HWCAP_VAR(x86_has_popcnt)
+MONO_HWCAP_VAR(x86_has_avx)
 
 #endif
