@@ -129,7 +129,8 @@ typedef enum {
 	MerpArchx86_64 = 1,
 	MerpArchx86 = 2,
 	MerpArchPPC = 3,
-	MerpArchPPC64 = 4
+	MerpArchPPC64 = 4,
+	MerpArchARM64 = 5
 } MerpArch;
 
 typedef enum
@@ -218,6 +219,8 @@ get_merp_bitness (MerpArch arch)
 			return "x64";
 		case MerpArchx86:
 			return "x32";
+		case MerpArchARM64:
+			return "arm64";
 		default:
 			g_assert_not_reached ();
 	}
@@ -234,6 +237,8 @@ get_merp_arch (void)
 	return MerpArchPPC;
 #elif defined(TARGET_POWERPC64)
 	return MerpArchPPC64;
+#elif defined(TARGET_ARM64)
+	return MerpArchARM64;
 #else
 	g_assert_not_reached ();
 #endif
@@ -324,10 +329,10 @@ mono_merp_write_params (MERPStruct *merp)
 	g_async_safe_fprintf(handle, "ApplicationPath: %s\n", merp->servicePathArg);
 	g_async_safe_fprintf(handle, "BlameModuleName: %s\n", merp->moduleName);
 	g_async_safe_fprintf(handle, "BlameModuleVersion: %s\n", merp->moduleVersion);
-	g_async_safe_fprintf(handle, "BlameModuleOffset: 0x%llx\n", (unsigned long long)merp->moduleOffset);
+	g_async_safe_fprintf(handle, "BlameModuleOffset: 0x%" PRIx64 "\n", (guint64)merp->moduleOffset);
 	g_async_safe_fprintf(handle, "ExceptionType: %s\n", get_merp_exctype (merp->exceptionArg));
-	g_async_safe_fprintf(handle, "StackChecksum: 0x%llx\n", merp->hashes.offset_free_hash);
-	g_async_safe_fprintf(handle, "StackHash: 0x%llx\n", merp->hashes.offset_rich_hash);
+	g_async_safe_fprintf(handle, "StackChecksum: 0x%" PRIx64 "\n", (guint64)merp->hashes.offset_free_hash);
+	g_async_safe_fprintf(handle, "StackHash: 0x%" PRIx64 "\n", (guint64)merp->hashes.offset_rich_hash);
 
 	// Provided by icall
 	g_async_safe_fprintf(handle, "OSVersion: %s\n", merp->osVersion);
@@ -460,8 +465,8 @@ mono_merp_write_fingerprint_payload (const char *non_param_data, const MERPStruc
 	g_async_safe_fprintf(handle, "\t\t\"BlameModuleVersion\" : \"%s\",\n", merp->moduleVersion);
 	g_async_safe_fprintf(handle, "\t\t\"BlameModuleOffset\" : \"0x%lx\",\n", merp->moduleOffset);
 	g_async_safe_fprintf(handle, "\t\t\"ExceptionType\" : \"%s\",\n", get_merp_exctype (merp->exceptionArg));
-	g_async_safe_fprintf(handle, "\t\t\"StackChecksum\" : \"0x%llx\",\n", merp->hashes.offset_free_hash);
-	g_async_safe_fprintf(handle, "\t\t\"StackHash\" : \"0x%llx\",\n", merp->hashes.offset_rich_hash);
+	g_async_safe_fprintf(handle, "\t\t\"StackChecksum\" : \"0x%" PRIx64 "\",\n", (guint64)merp->hashes.offset_free_hash);
+	g_async_safe_fprintf(handle, "\t\t\"StackHash\" : \"0x%" PRIx64 "\",\n", (guint64)merp->hashes.offset_rich_hash);
 	g_async_safe_fprintf(handle, "\t\t\"Extra\" : \n\t\t{\n");
 
 	for (GSList *cursor = merp->annotations; cursor; cursor = cursor->next) {
@@ -518,13 +523,13 @@ mono_write_wer_template (MERPStruct *merp)
 	i++;
 	g_async_safe_fprintf(handle, "<Parameter%d>%s</Parameter%d>\n", i, merp->moduleVersion, i);
 	i++;
-	g_async_safe_fprintf(handle, "<Parameter%d>0x%zx</Parameter%d>\n", i, merp->moduleOffset, i);
+	g_async_safe_fprintf(handle, "<Parameter%d>0x%" G_GSIZE_FORMAT "x</Parameter%d>\n", i, merp->moduleOffset, i);
 	i++;
 	g_async_safe_fprintf(handle, "<Parameter%d>%s</Parameter%d>\n", i, get_merp_exctype (merp->exceptionArg), i);
 	i++;
-	g_async_safe_fprintf(handle, "<Parameter%d>0x%llx</Parameter%d>\n", i, merp->hashes.offset_free_hash, i);
+	g_async_safe_fprintf(handle, "<Parameter%d>0x%" PRIx64 "</Parameter%d>\n", i, merp->hashes.offset_free_hash, i);
 	i++;
-	g_async_safe_fprintf(handle, "<Parameter%d>0x%llx</Parameter%d>\n", i, merp->hashes.offset_rich_hash, i);
+	g_async_safe_fprintf(handle, "<Parameter%d>0x%" PRIx64 "</Parameter%d>\n", i, merp->hashes.offset_rich_hash, i);
 	i++;
 	g_async_safe_fprintf(handle, "<Parameter%d>%s</Parameter%d>\n", i, merp->osVersion, i);
 	i++;
