@@ -131,10 +131,10 @@ mono_threads_state_poll_with_info (MonoThreadInfo *info)
 	THREADS_SUSPEND_DEBUG ("FINISH SELF SUSPEND OF %p\n", mono_thread_info_get_tid (info));
 
 	/* Fast fail if no_safepoints is set */
-	g_assert (!(info->thread_state & THREAD_SUSPEND_NO_SAFEPOINTS_MASK));
+	g_assert (!info->thread_state.no_safepoints);
 
 	/* Fast check for pending suspend requests */
-	if (!(info->thread_state & STATE_ASYNC_SUSPEND_REQUESTED))
+	if (info->thread_state.state != STATE_ASYNC_SUSPEND_REQUESTED)
 		return;
 
 	++coop_save_count;
