@@ -29,4 +29,10 @@ mono_native_thread_os_id_get (void)
 	return (guint64)getthrid ();
 }
 
+#else
+
+#include <mono/utils/mono-compiler.h>
+
+MONO_EMPTY_SOURCE_FILE (mono_threads_openbsd);
+
 #endif
